<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$languageStrings = Array(
    'Rss'=>'Rss',
    'LBL_RSS_FEED_SOURCES' => 'Surse RSS Feed',
    'LBL_ADD_FEED_SOURCE' => 'Adaugă alimentare Sursa',
    'LBL_FEEDS_LIST_FROM' => 'Fluxuri Lista Din',
    'LBL_SET_AS_DEFAULT' => 'Setare ca implicit',
    'LBL_SENDER' => 'transmițător',
    'LBL_FEED_SOURCE' => 'Sursa de alimentare',
    'LBL_ENTER_FEED_SOURCE' => 'Introduceți alimentare Sursa',  
    'SINGLE_Rss' => 'RSS Feed',
);

$jsLanguageStrings = array(
	'JS_RSS_SUCCESSFULLY_SAVED' => 'RSS salvat cu succes',
    'JS_INVALID_RSS_URL' => 'Invalid Adresă URL RSS',
    'JS_RSS_MADE_AS_DEFAULT' => 'RSS Made ca implicit',
    

  'JS_NO_RECORDS' => 'Nu Există Înregistrări',

);


?>